@@ -293,6 +293,10 @@ struct tcb {
 	 */
 	unsigned int pid_ns;
 
+# ifdef ENABLE_SECONTEXT
+	int last_dirfd; /* Use AT_FDCWD for 'not set' */
+# endif
+
 	struct mmap_cache_t *mmap_cache;
 
 	/*
@@ -800,9 +804,9 @@ extern int print_quoted_cstring(const char *, unsigned int);
 #  define ULONG_LONG(a, b) \
 	((unsigned long long)(unsigned)(a) | ((unsigned long long)(b)<<32))
 # endif
-extern int getllval(struct tcb *, unsigned long long *, int);
-extern int printllval(struct tcb *, const char *, int)
-	ATTRIBUTE_FORMAT((printf, 2, 0));
+extern unsigned int getllval(struct tcb *, unsigned long long *, unsigned int);
+extern unsigned int print_arg_lld(struct tcb *, unsigned int);
+extern unsigned int print_arg_llu(struct tcb *, unsigned int);
 
 extern void printaddr64(uint64_t addr);
 
@@ -921,16 +925,20 @@ extern bool print_int8_array_member(struct tcb *, void *elem_buf,
 				    size_t elem_size, void *data);
 extern bool print_uint8_array_member(struct tcb *, void *elem_buf,
 				     size_t elem_size, void *data);
+extern bool print_xint8_array_member(struct tcb *, void *elem_buf,
+				      size_t elem_size, void *data);
 extern bool print_int32_array_member(struct tcb *, void *elem_buf,
 				     size_t elem_size, void *data);
 extern bool print_uint32_array_member(struct tcb *, void *elem_buf,
 				      size_t elem_size, void *data);
-extern bool print_uint64_array_member(struct tcb *, void *elem_buf,
-				      size_t elem_size, void *data);
 extern bool print_xint32_array_member(struct tcb *, void *elem_buf,
 				      size_t elem_size, void *data);
+extern bool print_uint64_array_member(struct tcb *, void *elem_buf,
+				      size_t elem_size, void *data);
 extern bool print_xint64_array_member(struct tcb *, void *elem_buf,
 				      size_t elem_size, void *data);
+extern bool print_fd_array_member(struct tcb *, void *elem_buf,
+				  size_t elem_size, void *data);
 
 static inline bool
 print_xlong_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
@@ -1164,12 +1172,17 @@ extern void print_ax25_addr(const void /* ax25_address */ *addr);
 extern void print_x25_addr(const void /* struct x25_address */ *addr);
 extern const char *get_sockaddr_by_inode(struct tcb *, int fd, unsigned long inode);
 extern bool print_sockaddr_by_inode(struct tcb *, int fd, unsigned long inode);
+
+/**
+ * Prints dirfd file descriptor and saves it in tcp->last_dirfd,
+ * the latter is used when printing SELinux contexts.
+ */
 extern void print_dirfd(struct tcb *, int);
 
 extern int
 decode_sockaddr(struct tcb *, kernel_ulong_t addr, int addrlen);
 
-extern void printuid(const char *, const unsigned int);
+extern void printuid(const unsigned int);
 
 extern void
 print_sigset_addr_len(struct tcb *, kernel_ulong_t addr, kernel_ulong_t len);
@@ -1549,31 +1562,6 @@ printaddr_comment(const kernel_ulong_t addr)
 	tprintf_comment("%#llx", (unsigned long long) addr);
 }
 
-/*
- * When u64 is interpreted by the kernel as an address, there is a difference
- * in behaviour between 32-bit and 64-bit kernel in the way u64_to_user_ptr
- * works (32-bit kernel trims higher bits during conversion which may result
- * to a valid address).  Since 32-bit strace cannot figure out what kind of
- * kernel the tracee is running on, it has to account for both possibilities.
- */
-# if CAN_ARCH_BE_COMPAT_ON_64BIT_KERNEL
-
-/**
- * Print raw 64-bit value as an address if it's too big to fit in strace's
- * kernel_long_t.
- */
-static inline void
-print_big_u64_addr(const uint64_t addr)
-{
-	if (sizeof(kernel_long_t) < 8 && addr > max_kaddr()) {
-		printaddr64(addr);
-		tprints(" or ");
-	}
-}
-# else /* !CAN_ARCH_BE_COMPAT_ON_64BIT_KERNEL */
-#  define print_big_u64_addr(addr_) ((void) 0)
-# endif /* CAN_ARCH_BE_COMPAT_ON_64BIT_KERNEL */
-
 # if SIZEOF_KERNEL_LONG_T > 4		\
  && (SIZEOF_LONG < SIZEOF_KERNEL_LONG_T || !defined(current_wordsize))
 #  define ANY_WORDSIZE_LESS_THAN_KERNEL_LONG	1
@@ -1865,4 +1853,29 @@ ilog2_32(uint32_t val)
 
 # include "print_fields.h"
 
+/*
+ * When u64 is interpreted by the kernel as an address, there is a difference
+ * in behaviour between 32-bit and 64-bit kernel in the way u64_to_user_ptr
+ * works (32-bit kernel trims higher bits during conversion which may result
+ * to a valid address).  Since 32-bit strace cannot figure out what kind of
+ * kernel the tracee is running on, it has to account for both possibilities.
+ */
+# if CAN_ARCH_BE_COMPAT_ON_64BIT_KERNEL
+
+/**
+ * Print raw 64-bit value as an address if it's too big to fit in strace's
+ * kernel_long_t.
+ */
+static inline void
+print_big_u64_addr(const uint64_t addr)
+{
+	if (sizeof(kernel_long_t) < sizeof(addr) && addr > max_kaddr()) {
+		printaddr64(addr);
+		tprint_alternative_value();
+	}
+}
+# else /* !CAN_ARCH_BE_COMPAT_ON_64BIT_KERNEL */
+#  define print_big_u64_addr(addr_) ((void) 0)
+# endif /* CAN_ARCH_BE_COMPAT_ON_64BIT_KERNEL */
+
 #endif /* !STRACE_DEFS_H */
