@@ -14,6 +14,17 @@
 #include <linux/rtnetlink.h>
 #include <linux/xfrm.h>
 #include <linux/cryptouser.h>
+#include <linux/netfilter/ipset/ip_set.h>
+#include <linux/netfilter/nf_tables.h>
+#include <linux/netfilter/nf_tables_compat.h>
+#include <linux/netfilter/nfnetlink.h>
+#include <linux/netfilter/nfnetlink_acct.h>
+#include <linux/netfilter/nfnetlink_conntrack.h>
+#include <linux/netfilter/nfnetlink_cthelper.h>
+#include <linux/netfilter/nfnetlink_cttimeout.h>
+#include <linux/netfilter/nfnetlink_log.h>
+#include <linux/netfilter/nfnetlink_queue.h>
+#include <linux/netfilter/nfnetlink_osf.h>
 #include "xlat/netlink_ack_flags.h"
 #include "xlat/netlink_delete_flags.h"
 #include "xlat/netlink_flags.h"
@@ -318,6 +329,7 @@ decode_nlmsg_flags_netfilter(const uint16_t type)
 		case NFT_MSG_NEWSETELEM:
 		case NFT_MSG_NEWGEN:
 		case NFT_MSG_NEWOBJ:
+		case NFT_MSG_NEWFLOWTABLE:
 			return netlink_new_flags;
 		case NFT_MSG_GETTABLE:
 		case NFT_MSG_GETCHAIN:
@@ -327,6 +339,7 @@ decode_nlmsg_flags_netfilter(const uint16_t type)
 		case NFT_MSG_GETGEN:
 		case NFT_MSG_GETOBJ:
 		case NFT_MSG_GETOBJ_RESET:
+		case NFT_MSG_GETFLOWTABLE:
 			return netlink_get_flags;
 		case NFT_MSG_DELTABLE:
 		case NFT_MSG_DELCHAIN:
@@ -334,6 +347,7 @@ decode_nlmsg_flags_netfilter(const uint16_t type)
 		case NFT_MSG_DELSET:
 		case NFT_MSG_DELSETELEM:
 		case NFT_MSG_DELOBJ:
+		case NFT_MSG_DELFLOWTABLE:
 			return netlink_delete_flags;
 		}
 		break;
@@ -543,9 +557,7 @@ decode_nlmsgerr(struct tcb *const tcp,
 
 static const netlink_decoder_t netlink_decoders[] = {
 	[NETLINK_CRYPTO] = decode_netlink_crypto,
-#ifdef HAVE_LINUX_NETFILTER_NFNETLINK_H
 	[NETLINK_NETFILTER] = decode_netlink_netfilter,
-#endif
 	[NETLINK_ROUTE] = decode_netlink_route,
 	[NETLINK_SELINUX] = decode_netlink_selinux,
 	[NETLINK_SOCK_DIAG] = decode_netlink_sock_diag
