@@ -220,6 +220,7 @@ pathtrace_match_set(struct tcb *tcp, struct path_set *set)
 	case SEN_inotify_add_watch:
 	case SEN_mkdirat:
 	case SEN_mknodat:
+	case SEN_mount_setattr:
 	case SEN_name_to_handle_at:
 	case SEN_newfstatat:
 	case SEN_open_tree:
@@ -296,7 +297,7 @@ pathtrace_match_set(struct tcb *tcp, struct path_set *set)
 	{
 		/* x, x, mask (64 bit), fd, path */
 		unsigned long long mask = 0;
-		int argn = getllval(tcp, &mask, 2);
+		unsigned int argn = getllval(tcp, &mask, 2);
 		return fdmatch(tcp, tcp->u_arg[argn], set) ||
 			upathmatch(tcp, tcp->u_arg[argn + 1], set);
 	}
@@ -396,7 +397,7 @@ pathtrace_match_set(struct tcb *tcp, struct path_set *set)
 	case SEN_timerfd_settime64:
 	case SEN_userfaultfd:
 		/*
-		 * These have TRACE_FILE or TRACE_DESCRIPTOR or TRACE_NETWORK set,
+		 * These have TRACE_FILE or TRACE_DESC or TRACE_NETWORK set,
 		 * but they don't have any file descriptor or path args to test.
 		 */
 		return false;
