@@ -26,6 +26,7 @@
 #include "largefile_wrappers.h"
 #include "number_set.h"
 #include "print_utils.h"
+#include "secontext.h"
 #include "static_assert.h"
 #include "string_to_uint.h"
 #include "xlat.h"
@@ -263,8 +264,8 @@ next_set_bit(const void *bit_array, unsigned cur_bit, unsigned size_bits)
  * Fetch 64bit argument at position arg_no and
  * return the index of the next argument.
  */
-int
-getllval(struct tcb *tcp, unsigned long long *val, int arg_no)
+unsigned int
+getllval(struct tcb *tcp, unsigned long long *val, unsigned int arg_no)
 {
 #if SIZEOF_KERNEL_LONG_T > 4
 # ifndef current_klongsize
@@ -307,16 +308,30 @@ getllval(struct tcb *tcp, unsigned long long *val, int arg_no)
 }
 
 /*
- * Print 64bit argument at position arg_no and
- * return the index of the next argument.
+ * Print 64bit argument at position arg_no as a signed long long
+ * and return the index of the next argument.
  */
-int
-printllval(struct tcb *tcp, const char *format, int arg_no)
+unsigned int
+print_arg_lld(struct tcb *tcp, unsigned int arg_no)
 {
 	unsigned long long val = 0;
 
 	arg_no = getllval(tcp, &val, arg_no);
-	tprintf(format, val);
+	PRINT_VAL_D(val);
+	return arg_no;
+}
+
+/*
+ * Print 64bit argument at position arg_no as an unsigned long long
+ * and return the index of the next argument.
+ */
+unsigned int
+print_arg_llu(struct tcb *tcp, unsigned int arg_no)
+{
+	unsigned long long val = 0;
+
+	arg_no = getllval(tcp, &val, arg_no);
+	PRINT_VAL_U(val);
 	return arg_no;
 }
 
@@ -337,9 +352,9 @@ printnum_ ## name(struct tcb *const tcp, const kernel_ulong_t addr,	\
 	type num;							\
 	if (umove_or_printaddr(tcp, addr, &num))			\
 		return false;						\
-	tprints("[");							\
+	tprint_indirect_begin();					\
 	tprintf(fmt, num);						\
-	tprints("]");							\
+	tprint_indirect_end();						\
 	return true;							\
 }
 
@@ -350,9 +365,9 @@ printnum_addr_ ## name(struct tcb *tcp, const kernel_ulong_t addr)	\
 	type num;							\
 	if (umove_or_printaddr(tcp, addr, &num))			\
 		return false;						\
-	tprints("[");							\
+	tprint_indirect_begin();					\
 	printaddr64(num);						\
-	tprints("]");							\
+	tprint_indirect_end();						\
 	return true;							\
 }
 
@@ -364,11 +379,11 @@ printpair_ ## name(struct tcb *const tcp, const kernel_ulong_t addr,	\
 	type pair[2];							\
 	if (umove_or_printaddr(tcp, addr, &pair))			\
 		return false;						\
-	tprints("[");							\
+	tprint_indirect_begin();					\
 	tprintf(fmt, pair[0]);						\
 	tprints(", ");							\
 	tprintf(fmt, pair[1]);						\
-	tprints("]");							\
+	tprint_indirect_end();						\
 	return true;							\
 }
 
@@ -386,9 +401,9 @@ printnum_fd(struct tcb *const tcp, const kernel_ulong_t addr)
 	int fd;
 	if (umove_or_printaddr(tcp, addr, &fd))
 		return false;
-	tprints("[");
+	tprint_indirect_begin();
 	printfd(tcp, fd);
-	tprints("]");
+	tprint_indirect_end();
 	return true;
 }
 
@@ -398,9 +413,9 @@ printnum_pid(struct tcb *const tcp, const kernel_ulong_t addr, enum pid_type typ
 	int pid;
 	if (umove_or_printaddr(tcp, addr, &pid))
 		return false;
-	tprints("[");
+	tprint_indirect_begin();
 	printpid(tcp, pid, type);
-	tprints("]");
+	tprint_indirect_end();
 	return true;
 }
 
@@ -653,6 +668,13 @@ printed:
 	} else {
 		tprintf("%d", fd);
 	}
+#ifdef ENABLE_SECONTEXT
+	char *context;
+	if (!selinux_getfdcon(pid, fd, &context)) {
+		tprintf(" [%s]", context);
+		free(context);
+	}
+#endif
 }
 
 void
@@ -866,7 +888,7 @@ print_quoted_string_ex(const char *str, unsigned int size,
 	if (alloc_size / 4 != size) {
 		error_func_msg("requested %u bytes exceeds %u bytes limit",
 			       size, -1U / 4);
-		tprints("???");
+		tprint_unavailable();
 		return -1;
 	}
 	alloc_size += 1 + (style & QUOTE_OMIT_LEADING_TRAILING_QUOTES ? 0 : 2) +
@@ -880,7 +902,7 @@ print_quoted_string_ex(const char *str, unsigned int size,
 		if (!buf) {
 			error_func_msg("memory exhausted when tried to allocate"
 				       " %u bytes", alloc_size);
-			tprints("???");
+			tprint_unavailable();
 			return -1;
 		}
 	}
@@ -945,6 +967,14 @@ printpathn(struct tcb *const tcp, const kernel_ulong_t addr, unsigned int n)
 	else {
 		path[n++] = !nul_seen;
 		print_quoted_cstring(path, n);
+
+#ifdef ENABLE_SECONTEXT
+		char *context;
+		if (nul_seen && !selinux_getfilecon(tcp, path, &context)) {
+			tprintf(" [%s]", context);
+			free(context);
+		}
+#endif
 	}
 
 	return nul_seen;
@@ -1053,7 +1083,7 @@ print_nonzero_bytes(struct tcb *const tcp,
 		error_func_msg("memory exhausted when tried to allocate"
                                " %u bytes", len);
 		prefix_fun();
-		tprints("???");
+		tprint_unavailable();
 		return true;
 	}
 
@@ -1061,7 +1091,7 @@ print_nonzero_bytes(struct tcb *const tcp,
 
 	if (umoven(tcp, addr, len, str)) {
 		prefix_fun();
-		tprints("???");
+		tprint_unavailable();
 	} else if (is_filled(str, 0, len)) {
 		ret = false;
 	} else {
@@ -1327,6 +1357,15 @@ print_uint8_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
 	return true;
 }
 
+bool
+print_xint8_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
+			  void *data)
+{
+	tprintf("%#" PRIx8, *(uint8_t *) elem_buf);
+
+	return true;
+}
+
 bool
 print_int32_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
 			 void *data)
@@ -1346,19 +1385,19 @@ print_uint32_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
 }
 
 bool
-print_uint64_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
+print_xint32_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
 			  void *data)
 {
-	tprintf("%" PRIu64, *(uint64_t *) elem_buf);
+	tprintf("%#" PRIx32, *(uint32_t *) elem_buf);
 
 	return true;
 }
 
 bool
-print_xint32_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
+print_uint64_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
 			  void *data)
 {
-	tprintf("%#" PRIx32, *(uint32_t *) elem_buf);
+	tprintf("%" PRIu64, *(uint64_t *) elem_buf);
 
 	return true;
 }
@@ -1372,6 +1411,14 @@ print_xint64_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
 	return true;
 }
 
+bool
+print_fd_array_member(struct tcb *tcp, void *elem_buf, size_t elem_size,
+		      void *data)
+{
+	printfd(tcp, *(int *) elem_buf);
+	return true;
+}
+
 /*
  * Iteratively fetch and print up to nmemb elements of elem_size size
  * from the array that starts at tracee's address start_addr.
@@ -1433,7 +1480,7 @@ print_array_ex(struct tcb *const tcp,
 		if (tfetch_mem_func)
 			printaddr(start_addr);
 		else
-			tprints("???");
+			tprint_unavailable();
 		return false;
 	}
 
@@ -1475,7 +1522,7 @@ print_array_ex(struct tcb *const tcp,
 		}
 
 		if (flags & PAF_PRINT_INDICES) {
-			tprints("[");
+			tprint_array_index_begin();
 
 			if (!index_xlat) {
 				print_xlat_ex(idx, NULL, xlat_style);
@@ -1484,7 +1531,7 @@ print_array_ex(struct tcb *const tcp,
 					     index_dflt, xlat_style);
 			}
 
-			tprints("] = ");
+			tprint_array_index_end();
 		}
 
 		if (!print_func(tcp, elem_buf, elem_size, opaque_data)) {
