@@ -1,37 +1,17 @@
 /*
  * Check decoding of fanotify_mark syscall.
  *
- * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@strace.io>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2021 The strace developers.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
 
-#include <asm/unistd.h>
+#include "scno.h"
 
 #if defined HAVE_SYS_FANOTIFY_H && defined HAVE_FANOTIFY_MARK && \
 	defined __NR_fanotify_mark
@@ -41,20 +21,23 @@
 # include <unistd.h>
 # include <sys/fanotify.h>
 
-#if XLAT_RAW
-# define str_fan_mark_add	"0x1"
-# define str_fan_modify_ondir	"0x40000002"
-# define str_at_fdcwd		"-100"
-#elif XLAT_VERBOSE
-# define str_fan_mark_add	"0x1 /* FAN_MARK_ADD */"
-# define str_fan_modify_ondir	"0x40000002 /* FAN_MODIFY|FAN_ONDIR */"
-# define str_at_fdcwd		"-100 /* AT_FDCWD */"
-#else
-# define str_fan_mark_add	"FAN_MARK_ADD"
-# define str_fan_modify_ondir	"FAN_MODIFY|FAN_ONDIR"
-# define str_at_fdcwd		"AT_FDCWD"
-#endif
+# include "secontext.h"
 
+# if XLAT_RAW
+#  define str_fan_mark_add	"0x1"
+#  define str_fan_modify_ondir	"0x40000002"
+#  define str_at_fdcwd		"-100"
+# elif XLAT_VERBOSE
+#  define str_fan_mark_add	"0x1 /* FAN_MARK_ADD */"
+#  define str_fan_modify_ondir	"0x40000002 /* FAN_MODIFY|FAN_ONDIR */"
+#  define str_at_fdcwd		"-100 /* AT_FDCWD */"
+# else
+#  define str_fan_mark_add	"FAN_MARK_ADD"
+#  define str_fan_modify_ondir	"FAN_MODIFY|FAN_ONDIR"
+#  define str_at_fdcwd		"AT_FDCWD"
+# endif
+
+# ifndef TEST_SECONTEXT
 /* Performs fanotify_mark call via the syscall interface. */
 static void
 do_call(kernel_ulong_t fd, kernel_ulong_t flags, const char *flags_str,
@@ -64,18 +47,18 @@ do_call(kernel_ulong_t fd, kernel_ulong_t flags, const char *flags_str,
 	long rc;
 
 	rc = syscall(__NR_fanotify_mark, fd, flags,
-# if (LONG_MAX > INT_MAX) \
-  || (defined __x86_64__ && defined __ILP32__) \
-  || defined LINUX_MIPSN32
+#  if (LONG_MAX > INT_MAX) \
+   || (defined __x86_64__ && defined __ILP32__) \
+   || defined LINUX_MIPSN32
 		mask,
-# else
-/* arch/parisc/kernel/sys_parisc32.c, commit ab8a261b */
-#  ifdef HPPA
-		LL_VAL_TO_PAIR((mask << 32) | (mask >> 32)),
 #  else
+/* arch/parisc/kernel/sys_parisc32.c, commit ab8a261b */
+#   ifdef HPPA
+		LL_VAL_TO_PAIR((mask << 32) | (mask >> 32)),
+#   else
 		LL_VAL_TO_PAIR(mask),
+#   endif
 #  endif
-# endif
 		dirfd, path);
 
 	printf("fanotify_mark(%d, %s, %s, %s, %s) = %s\n",
@@ -88,17 +71,14 @@ struct strval {
 	const char *str;
 };
 
-struct strval64 {
-	uint64_t val;
-	const char *str;
-};
-
-#define STR16 "0123456789abcdef"
-#define STR64 STR16 STR16 STR16 STR16
+#  define STR16 "0123456789abcdef"
+#  define STR64 STR16 STR16 STR16 STR16
+# endif /* !TEST_SECONTEXT */
 
 int
 main(void)
 {
+# ifndef TEST_SECONTEXT
 	enum {
 		PATH1_SIZE = 64,
 	};
@@ -110,72 +90,91 @@ main(void)
 	};
 	static const struct strval flags[] = {
 		{ F8ILL_KULONG_MASK, "0" },
-		{ (kernel_ulong_t) 0xdec0deddefaced00ULL,
-			"0xefaced00"
-#if !XLAT_RAW
+		{ (kernel_ulong_t) 0xdec0deddefacec00ULL,
+			"0xefacec00"
+#  if !XLAT_RAW
 			" /* FAN_MARK_??? */"
-#endif
+#  endif
 			},
 		{ (kernel_ulong_t) 0xda7a105700000040ULL,
-#if XLAT_RAW
+#  if XLAT_RAW
 			"0x40"
-#elif XLAT_VERBOSE
+#  elif XLAT_VERBOSE
 			"0x40 /* FAN_MARK_IGNORED_SURV_MODIFY */"
-#else
+#  else
 			"FAN_MARK_IGNORED_SURV_MODIFY"
-#endif
+#  endif
 			},
-		{ (kernel_ulong_t) 0xbadc0deddeadfeedULL,
-#if XLAT_RAW || XLAT_VERBOSE
-			"0xdeadfeed"
-#endif
-#if XLAT_VERBOSE
+		{ (kernel_ulong_t) 0xbadc0deddeadffffULL,
+#  if XLAT_RAW || XLAT_VERBOSE
+			"0xdeadffff"
+#  endif
+#  if XLAT_VERBOSE
 			" /* "
-#endif
-#if !XLAT_RAW
-			"FAN_MARK_ADD|FAN_MARK_DONT_FOLLOW|FAN_MARK_ONLYDIR|"
-			"FAN_MARK_IGNORED_MASK|FAN_MARK_IGNORED_SURV_MODIFY|"
-			"FAN_MARK_FLUSH|0xdeadfe00"
-#endif
-#if XLAT_VERBOSE
+#  endif
+#  if !XLAT_RAW
+			"FAN_MARK_ADD|FAN_MARK_REMOVE|FAN_MARK_DONT_FOLLOW|"
+			"FAN_MARK_ONLYDIR|FAN_MARK_MOUNT|FAN_MARK_IGNORED_MASK|"
+			"FAN_MARK_IGNORED_SURV_MODIFY|FAN_MARK_FLUSH|"
+			"FAN_MARK_FILESYSTEM|0xdeadfe00"
+#  endif
+#  if XLAT_VERBOSE
 			" */"
-#endif
+#  endif
 			},
 	};
 	static const struct strval64 masks[] = {
 		{ ARG_ULL_STR(0) },
-		{ 0xdeadfeedfacebeefULL,
-#if XLAT_RAW || XLAT_VERBOSE
-			"0xdeadfeedfacebeef"
-#endif
-#if XLAT_VERBOSE
+		{ 0xdeadfeedffffffffULL,
+#  if XLAT_RAW || XLAT_VERBOSE
+			"0xdeadfeedffffffff"
+#  endif
+#  if XLAT_VERBOSE
 			" /* "
-#endif
-#if !XLAT_RAW
-			"FAN_ACCESS|FAN_MODIFY|FAN_CLOSE_WRITE|FAN_OPEN|"
-			"FAN_ACCESS_PERM|FAN_ONDIR|FAN_EVENT_ON_CHILD|"
-			"0xdeadfeedb2ccbec4"
-#endif
-#if XLAT_VERBOSE
+#  endif
+#  if !XLAT_RAW
+			"FAN_ACCESS|"
+			"FAN_MODIFY|"
+			"FAN_ATTRIB|"
+			"FAN_CLOSE_WRITE|"
+			"FAN_CLOSE_NOWRITE|"
+			"FAN_OPEN|"
+			"FAN_MOVED_FROM|"
+			"FAN_MOVED_TO|"
+			"FAN_CREATE|"
+			"FAN_DELETE|"
+			"FAN_DELETE_SELF|"
+			"FAN_MOVE_SELF|"
+			"FAN_OPEN_EXEC|"
+			"FAN_Q_OVERFLOW|"
+			"FAN_OPEN_PERM|"
+			"FAN_ACCESS_PERM|"
+			"FAN_OPEN_EXEC_PERM|"
+			"FAN_DIR_MODIFY|"
+			"FAN_ONDIR|"
+			"FAN_EVENT_ON_CHILD|"
+			"0xdeadfeedb7f0a000"
+#  endif
+#  if XLAT_VERBOSE
 			" */"
-#endif
+#  endif
 			},
-		{ ARG_ULL_STR(0xffffffffb7fcbfc4)
-#if !XLAT_RAW
+		{ ARG_ULL_STR(0xffffffffb7f0a000)
+#  if !XLAT_RAW
 			" /* FAN_??? */"
-#endif
+#  endif
 			},
 	};
 	static const struct strval dirfds[] = {
 		{ (kernel_ulong_t) 0xfacefeed00000001ULL, "1" },
 		{ (kernel_ulong_t) 0xdec0ded0ffffffffULL,
-#if XLAT_RAW
+#  if XLAT_RAW
 			"-1"
-#elif XLAT_VERBOSE
+#  elif XLAT_VERBOSE
 			"-1 /* FAN_NOFD */"
-#else
+#  else
 			"FAN_NOFD"
-#endif
+#  endif
 			},
 		{ (kernel_ulong_t) 0xbadfacedffffff9cULL, str_at_fdcwd },
 		{ (kernel_ulong_t) 0xdefaced1beeff00dULL, "-1091571699" },
@@ -208,12 +207,6 @@ main(void)
 	snprintf(bogus_path1_after_addr, sizeof(bogus_path1_after_addr), "%p",
 		bogus_path1 + PATH1_SIZE);
 
-	rc = fanotify_mark(-1, FAN_MARK_ADD, FAN_MODIFY | FAN_ONDIR,
-			       -100, ".");
-	printf("fanotify_mark(-1, %s, %s, %s, \".\") = %s\n",
-	       str_fan_mark_add, str_fan_modify_ondir, str_at_fdcwd,
-	       sprintrc(rc));
-
 	for (i = 0; i < ARRAY_SIZE(fds); i++) {
 		for (j = 0; j < ARRAY_SIZE(flags); j++) {
 			for (k = 0; k < ARRAY_SIZE(masks); k++) {
@@ -232,6 +225,40 @@ main(void)
 			}
 		}
 	}
+# else /* TEST_SECONTEXT */
+	int rc;
+# endif
+	/*
+	 * Test with AT_FDCWD.
+	 */
+
+	char *my_secontext = SECONTEXT_PID_MY();
+	char path[] = ".";
+	char *path_secontext = SECONTEXT_FILE(path);
+
+	rc = fanotify_mark(-1, FAN_MARK_ADD, FAN_MODIFY | FAN_ONDIR,
+			   -100, path);
+	printf("%s%s(-1, %s, %s, %s, \"%s\"%s) = %s\n",
+	       my_secontext, "fanotify_mark",
+	       str_fan_mark_add, str_fan_modify_ondir, str_at_fdcwd,
+	       path, path_secontext,
+	       sprintrc(rc));
+
+	/*
+	 * Test with dirfd.
+	 */
+
+	int cwd_fd = get_dir_fd(".");
+	char *cwd_secontext = SECONTEXT_FILE(".");
+
+	rc = fanotify_mark(-1, FAN_MARK_ADD, FAN_MODIFY | FAN_ONDIR,
+			   cwd_fd, path);
+	printf("%s%s(-1, %s, %s, %d%s, \"%s\"%s) = %s\n",
+	       my_secontext, "fanotify_mark",
+	       str_fan_mark_add, str_fan_modify_ondir,
+	       cwd_fd, cwd_secontext,
+	       path, path_secontext,
+	       sprintrc(rc));
 
 	puts("+++ exited with 0 +++");
 	return 0;
