@@ -1,45 +1,39 @@
 /*
  * Check decoding of io_uring_register syscall.
  *
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2019-2020 The strace developers.
+ * Copyright (c) 2019 Dmitry V. Levin <ldv@strace.io>
+ * Copyright (c) 2019-2021 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <unistd.h>
 #include "scno.h"
 
-#ifdef __NR_io_uring_register
-
-# include <fcntl.h>
-# include <inttypes.h>
-# include <stdio.h>
-# include <string.h>
-# include <sys/uio.h>
-
-# ifdef HAVE_LINUX_IO_URING_H
-#  include <linux/io_uring.h>
-# endif
+#include <fcntl.h>
+#include <inttypes.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <linux/io_uring.h>
 
 /* From tests/bpf.c */
-# if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
-#  define BIG_ADDR_MAYBE(addr_)
-# elif defined __arm__ || defined __i386__ || defined __mips__ \
+#if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
+# define BIG_ADDR_MAYBE(addr_)
+#elif defined __arm__ || defined __i386__ || defined __mips__ \
    || defined __powerpc__ || defined __riscv__ || defined __s390__ \
    || defined __sparc__ || defined __tile__
-#  define BIG_ADDR_MAYBE(addr_) addr_ " or "
-# else
-#  define BIG_ADDR_MAYBE(addr_)
-# endif
+# define BIG_ADDR_MAYBE(addr_) addr_ " or "
+#else
+# define BIG_ADDR_MAYBE(addr_)
+#endif
 
-# if WORDS_BIGENDIAN
-#  define BE_LE(be_, le_) be_
-# else
-#  define BE_LE(be_, le_) le_
-# endif
+#ifdef WORDS_BIGENDIAN
+# define BE_LE(be_, le_) be_
+#else
+# define BE_LE(be_, le_) le_
+#endif
 
 static const char *errstr;
 
@@ -91,7 +85,7 @@ main(void)
 	int fds[] = { fd_full, fd_null };
 	const int *arg_fds = tail_memdup(fds, sizeof(fds));
 
-	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 11 };
+	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 13 };
 
 	for (size_t i = 0; i < ARRAY_SIZE(invalid_ops); i++) {
 		sys_io_uring_register(fd_null, invalid_ops[i], path_null,
@@ -149,7 +143,6 @@ main(void)
 		       (unsigned int) ARRAY_SIZE(fds), errstr);
 	}
 
-# ifdef HAVE_STRUCT_IO_URING_FILES_UPDATE
 	struct io_uring_files_update bogus_iufu;
 	struct io_uring_files_update iufu;
 
@@ -176,9 +169,7 @@ main(void)
 	       ", {offset=3735929054, fds=[%u<%s>, %u<%s>]}, %u) = %s\n",
 	       fd_null, path_null, fd_full, path_full, fd_null, path_null,
 	       (unsigned int) ARRAY_SIZE(fds), errstr);
-# endif
 
-# ifdef HAVE_STRUCT_IO_URING_PROBE
 	struct io_uring_probe *probe = tail_alloc(sizeof(*probe) +
 		       (DEFAULT_STRLEN + 1) * sizeof(struct io_uring_probe_op));
 
@@ -225,12 +216,12 @@ main(void)
 	probe->ops[0].flags = 0;
 	probe->ops[0].resv2 = 0xbeefface;
 
-	probe->ops[1].op = 32;
+	probe->ops[1].op = 36;
 	probe->ops[1].resv = 0;
 	probe->ops[1].flags = IO_URING_OP_SUPPORTED;
 	probe->ops[1].resv2 = 0xdeadc0de;
 
-	probe->ops[2].op = 33;
+	probe->ops[2].op = 37;
 	probe->ops[2].resv = 0xaf;
 	probe->ops[2].flags = 0xbeef;
 	probe->ops[2].resv2 = 0;
@@ -245,22 +236,22 @@ main(void)
 	       ", {last_op=IORING_OP_EPOLL_CTL, ops_len=%hhu"
 	       ", resv2=[0, %#x, 0], ops=["
 	       "{op=IORING_OP_NOP, resv=0xde, flags=0, resv2=0xbeefface}, "
-	       "{op=IORING_OP_REMOVE_BUFFERS, flags=IO_URING_OP_SUPPORTED"
+	       "{op=IORING_OP_UNLINKAT, flags=IO_URING_OP_SUPPORTED"
 	       ", resv2=0xdeadc0de}, "
-	       "{op=33 /* IORING_OP_??? */, resv=0xaf"
+	       "{op=37 /* IORING_OP_??? */, resv=0xaf"
 	       ", flags=IO_URING_OP_SUPPORTED|0xbeee}, "
 	       "{op=254 /* IORING_OP_??? */"
 	       ", flags=0xc0de /* IO_URING_OP_??? */}]}, 4) = %s\n",
 	       fd_null, path_null, probe->ops_len, probe->resv2[1], errstr);
 
-	probe->last_op = 33;
+	probe->last_op = 37;
 	probe->resv2[1] = 0;
 	fill_memory_ex(probe->ops, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1),
 		    0x40, 0x80);
 	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe,
 			      DEFAULT_STRLEN + 1);
 	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
-	       ", {last_op=33 /* IORING_OP_??? */, ops_len=%hhu, ops=[",
+	       ", {last_op=37 /* IORING_OP_??? */, ops_len=%hhu, ops=[",
 	       fd_null, path_null, probe->ops_len);
 	for (size_t i = 0; i < DEFAULT_STRLEN; i++) {
 		printf("%s{op=%u /* IORING_OP_??? */, resv=%#hhx"
@@ -280,14 +271,7 @@ main(void)
 	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 8);
 	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE, %p, 8) = %s\n",
 	       fd_null, path_null, probe, errstr);
-# endif
 
 	puts("+++ exited with 0 +++");
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("__NR_io_uring_register")
-
-#endif
