@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 JingPiao Chen <chenjingpiao@foxmail.com>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2021 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,13 +11,10 @@
 
 #include "tests.h"
 #include "scno.h"
+#include <stdio.h>
+#include <unistd.h>
 #include <linux/prctl.h>
 
-#if defined __NR_prctl && defined PR_GET_TSC && defined PR_SET_TSC
-
-# include <stdio.h>
-# include <unistd.h>
-
 int
 main(void)
 {
@@ -53,9 +50,3 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("__NR_prctl && PR_GET_TSC && PR_SET_TSC")
-
-#endif
