@@ -3,51 +3,30 @@
  * mq_unlink syscalls.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2017 The strace developers.
+ * Copyright (c) 2016-2021 The strace developers.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
-#include <asm/unistd.h>
+#include "scno.h"
 
 #if defined __NR_mq_open && __NR_mq_timedsend && __NR_mq_timedreceive && \
 	__NR_mq_notify && __NR_mq_unlink
 
 # include <assert.h>
 # include <errno.h>
-# include <fcntl.h>
 # include <inttypes.h>
 # include <signal.h>
-# include <stdbool.h>
 # include <stdio.h>
 # include <stdlib.h>
 # include <string.h>
 # include <time.h>
 # include <unistd.h>
 
+# include "xmalloc.h"
+# include "kernel_fcntl.h"
 # include "sigevent.h"
 
 # ifndef DUMPIO_READ
@@ -81,7 +60,7 @@ printstr(unsigned char start, unsigned int count)
 	printf("\"");
 }
 
-#if DUMPIO_READ || DUMPIO_WRITE
+# if DUMPIO_READ || DUMPIO_WRITE
 static void
 dumpstr(unsigned char start, unsigned int count)
 {
@@ -115,7 +94,7 @@ dumpstr(unsigned char start, unsigned int count)
 		}
 	}
 }
-#endif /* DUMPIO_READ || DUMPIO_WRITE */
+# endif /* DUMPIO_READ || DUMPIO_WRITE */
 
 static void
 cleanup(void)
@@ -232,7 +211,8 @@ main(void)
 	struct_sigevent bogus_sev_data = {
 		.sigev_notify = 0xdefaced,
 		.sigev_signo = 0xfacefeed,
-		.sigev_value.sival_ptr = (unsigned long) 0xdeadbeefbadc0dedULL
+		.sigev_value.sival_ptr =
+			(void *) (unsigned long) 0xdeadbeefbadc0dedULL
 	};
 
 	const char *errstr;
@@ -369,7 +349,7 @@ main(void)
 
 	/* Invalid SIGEV_* */
 	rc = syscall(__NR_mq_notify, bogus_fd, bogus_sev);
-	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%#lx}"
+	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%p}"
 	       ", sigev_signo=%u, sigev_notify=%#x /* SIGEV_??? */}) = %s\n",
 	       (int) bogus_fd, bogus_sev->sigev_value.sival_int,
 	       bogus_sev->sigev_value.sival_ptr,
@@ -379,7 +359,7 @@ main(void)
 	/* SIGEV_NONE */
 	bogus_sev->sigev_notify = SIGEV_NONE;
 	rc = syscall(__NR_mq_notify, bogus_fd, bogus_sev);
-	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%#lx}"
+	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%p}"
 	       ", sigev_signo=%u, sigev_notify=SIGEV_NONE}) = %s\n",
 	       (int) bogus_fd, bogus_sev->sigev_value.sival_int,
 	       bogus_sev->sigev_value.sival_ptr,
@@ -389,7 +369,7 @@ main(void)
 	bogus_sev->sigev_notify = SIGEV_SIGNAL;
 	bogus_sev->sigev_signo = SIGALRM;
 	rc = syscall(__NR_mq_notify, bogus_fd, bogus_sev);
-	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%#lx}"
+	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%p}"
 	       ", sigev_signo=SIGALRM, sigev_notify=SIGEV_SIGNAL}) = %s\n",
 	       (int) bogus_fd, bogus_sev->sigev_value.sival_int,
 	       bogus_sev->sigev_value.sival_ptr, sprintrc(rc));
@@ -397,13 +377,13 @@ main(void)
 	/* SIGEV_THREAD */
 	bogus_sev->sigev_notify = SIGEV_THREAD;
 	bogus_sev->sigev_un.sigev_thread.function =
-		(unsigned long) 0xdeadbeefbadc0dedULL;
+		(void *) (unsigned long) 0xdeadbeefbadc0dedULL;
 	bogus_sev->sigev_un.sigev_thread.attribute =
-		(unsigned long) 0xcafef00dfacefeedULL;
+		(void *) (unsigned long) 0xcafef00dfacefeedULL;
 	rc = syscall(__NR_mq_notify, bogus_fd, bogus_sev);
-	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%#lx}"
+	printf("mq_notify(%d, {sigev_value={sival_int=%d, sival_ptr=%p}"
 	       ", sigev_signo=SIGALRM, sigev_notify=SIGEV_THREAD"
-	       ", sigev_notify_function=%#lx, sigev_notify_attributes=%#lx})"
+	       ", sigev_notify_function=%p, sigev_notify_attributes=%p})"
 	       " = %s\n",
 	       (int) bogus_fd, bogus_sev->sigev_value.sival_int,
 	       bogus_sev->sigev_value.sival_ptr,
@@ -428,8 +408,7 @@ main(void)
 
 	/* Sending and receiving test */
 
-	if (asprintf(&mq_name, "strace-mq_sendrecv-%u.sample", getpid()) < 0)
-		perror_msg_and_fail("asprintf");
+	mq_name = xasprintf("strace-mq_sendrecv-%u.sample", getpid());
 
 # if DUMPIO_READ || DUMPIO_WRITE
 	close(0);
@@ -437,7 +416,7 @@ main(void)
 	bogus_attrs[1] = 2;
 	bogus_attrs[2] = MSG_SIZE;
 	fd = rc = syscall(__NR_mq_open, mq_name,
-			  O_CREAT|O_RDWR|O_NONBLOCK, S_IRWXU, bogus_attrs);
+			  O_CREAT|O_RDWR|O_NONBLOCK, 0700, bogus_attrs);
 	errstr = sprintrc(rc);
 	if (rc < 0)
 		perror_msg_and_skip("mq_open");
