@@ -1,35 +1,21 @@
 /*
  * Copyright (c) 2017, 2018 Chen Jingpiao <chenjingpiao@gmail.com>
+ * Copyright (c) 2017-2021 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
-#ifdef HAVE_LINUX_NETFILTER_NFNETLINK_H
-
-# include <stdio.h>
-# include <string.h>
-# include <unistd.h>
-# include <netinet/in.h>
-# include <arpa/inet.h>
-# include <sys/socket.h>
-# include "test_netlink.h"
-# include <linux/netfilter/nfnetlink.h>
-# ifdef HAVE_LINUX_NETFILTER_NF_TABLES_H
-#  include <linux/netfilter/nf_tables.h>
-# endif
-
-# ifndef NFNETLINK_V0
-#  define NFNETLINK_V0 0
-# endif
-# ifndef NFNL_SUBSYS_NFTABLES
-#  define NFNL_SUBSYS_NFTABLES 10
-# endif
-# ifndef NFT_MSG_NEWTABLE
-#  define NFT_MSG_NEWTABLE 0
-# endif
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <sys/socket.h>
+#include "test_netlink.h"
+#include <linux/netfilter/nfnetlink.h>
+#include <linux/netfilter/nf_tables.h>
 
 static void
 test_nlmsg_type(const int fd)
@@ -40,28 +26,26 @@ test_nlmsg_type(const int fd)
 		.nlmsg_flags = NLM_F_REQUEST,
 	};
 
-# ifdef NFNL_MSG_BATCH_BEGIN
 	nlh.nlmsg_type = NFNL_MSG_BATCH_BEGIN;
 	rc = sendto(fd, &nlh, sizeof(nlh), MSG_DONTWAIT, NULL, 0);
-	printf("sendto(%d, {len=%u, type=NFNL_MSG_BATCH_BEGIN"
-	       ", flags=NLM_F_REQUEST, seq=0, pid=0}"
+	printf("sendto(%d, {nlmsg_len=%u, nlmsg_type=NFNL_MSG_BATCH_BEGIN"
+	       ", nlmsg_flags=NLM_F_REQUEST, nlmsg_seq=0, nlmsg_pid=0}"
 	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh.nlmsg_len, (unsigned) sizeof(nlh), sprintrc(rc));
-# endif
 
 	nlh.nlmsg_type = NFNL_SUBSYS_CTNETLINK << 8 | 0xff;
 	rc = sendto(fd, &nlh, sizeof(nlh), MSG_DONTWAIT, NULL, 0);
-	printf("sendto(%d, {len=%u"
-	       ", type=NFNL_SUBSYS_CTNETLINK<<8|0xff /* IPCTNL_MSG_CT_??? */"
-	       ", flags=NLM_F_REQUEST, seq=0, pid=0}"
-	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
+	printf("sendto(%d, {nlmsg_len=%u"
+	       ", nlmsg_type=NFNL_SUBSYS_CTNETLINK<<8|0xff"
+	       " /* IPCTNL_MSG_CT_??? */, nlmsg_flags=NLM_F_REQUEST"
+	       ", nlmsg_seq=0, nlmsg_pid=0}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh.nlmsg_len, (unsigned) sizeof(nlh), sprintrc(rc));
 
 	nlh.nlmsg_type = 0xffff;
 	rc = sendto(fd, &nlh, sizeof(nlh), MSG_DONTWAIT, NULL, 0);
-	printf("sendto(%d, {len=%u, type=0xff /* NFNL_SUBSYS_??? */<<8|0xff"
-	       ", flags=NLM_F_REQUEST, seq=0, pid=0}"
-	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
+	printf("sendto(%d, {nlmsg_len=%u, nlmsg_type=0xff"
+	       " /* NFNL_SUBSYS_??? */<<8|0xff, nlmsg_flags=NLM_F_REQUEST"
+	       ", nlmsg_seq=0, nlmsg_pid=0}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh.nlmsg_len, (unsigned) sizeof(nlh), sprintrc(rc));
 }
 
@@ -129,7 +113,6 @@ test_nfgenmsg(const int fd)
 		      printf(", version=NFNETLINK_V0");
 		      printf(", res_id=htons(%d)", 0xabcd));
 
-# ifdef NFNL_MSG_BATCH_BEGIN
 	msg.res_id = htons(NFNL_SUBSYS_NFTABLES);
 	TEST_NETLINK(fd, nlh0,
 		     NFNL_MSG_BATCH_BEGIN, NLM_F_REQUEST,
@@ -149,7 +132,6 @@ test_nfgenmsg(const int fd)
 		     printf(", version=NFNETLINK_V0");
 		     printf(", res_id=htons(%d)"
 			    ", \"\\x31\\x32\\x33\\x34\"", 0xabcd));
-# endif /* NFNL_MSG_BATCH_BEGIN */
 
 	msg.res_id = htons(NFNL_SUBSYS_NFTABLES);
 	memcpy(nla_buf, &msg, sizeof(msg));
@@ -181,9 +163,3 @@ int main(void)
 
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("HAVE_LINUX_NETFILTER_NFNETLINK_H")
-
-#endif
