@@ -3,21 +3,18 @@
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2016-2020 The strace developers.
+ * Copyright (c) 2016-2021 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
 #include <sys/prctl.h>
 
-#if defined PR_GET_NAME && defined PR_SET_NAME
-
-# include <stdio.h>
-# include <string.h>
-# include <unistd.h>
-
 int
 main(void)
 {
@@ -73,9 +70,3 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("PR_GET_NAME && PR_SET_NAME")
-
-#endif
