@@ -1,8 +1,8 @@
 /*
  * Check verbose decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
- * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2020 The strace developers.
+ * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@strace.io>
+ * Copyright (c) 2016-2021 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,16 +15,12 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/prctl.h>
-#ifdef HAVE_LINUX_SECCOMP_H
-# include <linux/seccomp.h>
-#endif
+#include <linux/seccomp.h>
 #include <linux/filter.h>
 #include "scno.h"
 
 #if defined __NR_seccomp \
  && defined PR_SET_NO_NEW_PRIVS \
- && defined SECCOMP_SET_MODE_FILTER \
- && defined SECCOMP_RET_ERRNO \
  && defined BPF_JUMP \
  && defined BPF_STMT
 
@@ -115,7 +111,8 @@ main(void)
 	tprintf("seccomp(SECCOMP_SET_MODE_FILTER, %s, {len=%u, filter=[",
 		"SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
 		"SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
-		"SECCOMP_FILTER_FLAG_NEW_LISTENER|0xfffffff0",
+		"SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+		"SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 		prog->len);
 	for (i = 0; i < BPF_MAXINSNS; ++i) {
 		if (i)
@@ -182,7 +179,6 @@ main(void)
 #else
 
 SKIP_MAIN_UNDEFINED("__NR_seccomp && PR_SET_NO_NEW_PRIVS"
-		    " && SECCOMP_SET_MODE_FILTER && SECCOMP_RET_ERRNO"
 		    " && BPF_JUMP && BPF_STMT")
 
 #endif
