@@ -16,14 +16,7 @@
 
 # include <stdio.h>
 # include <unistd.h>
-
-# ifdef HAVE_LINUX_UTSNAME_H
-#  include <linux/utsname.h>
-# endif
-
-# ifndef __NEW_UTS_LEN
-#  define __NEW_UTS_LEN 64
-# endif
+# include <linux/utsname.h>
 
 int
 main(void)
